<html>
<head>

    <title>Django JFU</title>
    <meta charset="utf-8">

    <style>
        body {
          padding-top: 100px;
        }
    </style> 

    <!-- Piwik -->
    <script type="text/javascript">
      var _paq = _paq || [];
      _paq.push(["trackPageView"]);
      _paq.push(["enableLinkTracking"]);

      (function() {
        var u=(("https:" == document.location.protocol) ? "https" : "http") + "://www.alemcode.com/piwik/";
        _paq.push(["setTrackerUrl", u+"piwik.php"]);
        _paq.push(["setSiteId", "9"]);
        var d=document, g=d.createElement("script"), s=d.getElementsByTagName("script")[0]; g.type="text/javascript";
        g.defer=true; g.async=true; g.src=u+"piwik.js"; s.parentNode.insertBefore(g,s);
      })();
    </script>
    <!-- End Piwik Code -->

</head>

  <body>


  <div class="navbar navbar-inverse navbar-fixed-top" role="navigation">
      <div class="container">
        <div class="navbar-header">
          <a class="navbar-brand" href="#">Django-JFU</a>
        </div>
      </div>
    </div>

    <div class="container">

      <div class="hero-unit">
        {% load jfutags %}
        {% jfu 'photo_upload_form.html' %}
      </div>
      
      <div class = 'help' >
        <h3>The work involved</h3>

        <div class='row'>
            <div>
                <h4>Template</h4>
<pre>{% verbatim %}{% load jfutags %} 
{% jfu 'photo_upload_form.html' %} {% endverbatim %}</pre>
            </div>

            <div>
                <h4>photo_upload_form.html</h4>
                <pre>{% with ""|add:project_root|add:"/photos/templates/photo_upload_form.html" as upform %}{% ssi upform %} {% endwith %}</pre>
            </div>

            <div>
                <h4>urls.py</h4>
                <pre>{% with ""|add:project_root|add:"/demo/urls.py" as urls %}{% ssi urls %} {% endwith %}</pre>
            </div>

            <div>
                <h4>views.py</h4>
                <pre>{% with ""|add:project_root|add:"/photos/views.py" as views %}{% ssi views %} {% endwith %}</pre>
            </div>
        </div>

      </div>

    </div>

   <hr>

  <footer>
    <p>&copy; <a href='http://cidola.com'>Cidola</a> 2013 </p>
  </footer>

</body>
</html>
